@@ -1,6 +1,6 @@
 package Cuitter;
 use vars qw($VERSION);
-$VERSION = 0.001003;
+$VERSION = 0.001004;
 
 use Mouse;
 use Net::Netrc;
@@ -8,9 +8,7 @@ use Net::Twitter::Lite;
 use IO::Handle;
 use Encode;
 use POSIX qw( strftime );
-use DateTime::Format::DateParse;
 use Cache::FileCache;
-use Data::Dumper;
 
 with qw( MouseX::Getopt MouseX::Object::Pluggable );
 
@@ -18,17 +16,16 @@ has username => ( is => 'rw', isa => 'Str' );
 has client => ( is => 'rw', isa => 'Object' );
 has input => ( is => 'rw', isa => 'FileHandle' );
 has output => ( is => 'rw', isa => 'FileHandle' );
-has help => ( is => 'rw', isa => 'HashRef' );
 has status => ( is => 'rw', isa => 'ArrayRef', clearer => 'clear_status' );
 has rows => ( is => 'rw', isa => 'Int' );
-has plugins => ( is => 'ro', isa => 'ArrayRef' );
+has plugins => ( is => 'rw', isa => 'ArrayRef' );
 has cache => ( is => 'rw', isa => 'Object' );
 
 sub BUILD {
     my $self = shift;
-    $self->help( {} );
     $| = 1;
-    $self->load_plugins( 'OAuth' );
+    $self->plugins( [] ) unless $self->plugins;
+    unshift @{ $self->plugins }, qw( Help Core Aliases OAuth );
     if ( $self->plugins ) {
         $self->load_plugins( @{ $self->plugins } );
         for my $plugin ( @{ $self->plugins } ) {
@@ -41,9 +38,6 @@ sub BUILD {
     $self->input->fdopen( fileno( STDIN ), 'r' );
     $self->output( IO::Handle->new );
     $self->output->fdopen( fileno( STDOUT ), 'w' );
-    $self->set_help( 'help', '( command ) show help of command.' );
-    $self->set_help( 'exit', 'exit from cuitter' );
-    $self->set_help( 'ft', 'show friends time-line.' );
     $self->cache( Cache::FileCache->new( { namespace => __PACKAGE__ } ) );
     $self->login;
     $self->loop if $self->username;
@@ -108,115 +102,6 @@ sub _netrc_init {
     $self->output->print( "saved to ". $ENV{ HOME }. '/.netrc'. "\n" );
 }
 
-sub prompt {
-    my $self = shift;
-    $self->output->print( '@'.$self->username.": " );
-    my $line = $self->input->getline;
-    chomp $line;
-    $line = '/ft' unless $line;
-    if ( $line =~ /^\// ) {
-        $line =~ s/^\///;
-        my ( $command, @arg ) = split / /, $line;
-        my $exec = "com_$command";
-        if ( $self->can( "$exec" ) ) {
-            return $self->$exec( @arg );
-        }
-        else {
-            $self->output->print( "$command ? I don't know it.\n" );
-            return 1;
-        }
-    }
-    else {
-        $self->tweet( $line );
-        $self->com_ft;
-        return 1;
-    }
-}
-
-sub loop {
-    my $self = shift;
-    while ( $self->prompt ) {};
-}
-
-sub tweet {
-    my ( $self, $line ) = @_;
-    $self->client->update( $line );
-}
-
-sub set_help {
-    my ( $self, $name, $comment ) = @_;
-    $self->help->{ "$name" } = $comment;
-}
-
-sub get_help {
-    my ( $self, $name ) = @_;
-    if ( $name ) {
-        return "$name : ". $self->help->{ "$name" }."\n";
-    }
-    else {
-        my $rtn = "";
-        for my $key ( keys %{ $self->help } ) {
-            $rtn .= "/$key : ".$self->help->{ "$key" }."\n";
-        }
-        return $rtn;
-    }
-}
-
-sub com_help {
-    my ( $self, $command ) = @_;
-    $self->output->print( $self->get_help( $command ) );
-    1;
-}
-
-sub com_exit {
-    my $self = shift;
-    $self->output->print( "Sayonara.\n" );
-    return;
-}
-sub com_q { shift->com_exit }
-sub com_quit { shift->com_exit }
-sub com_bye { shift->com_exit }
-sub com_sayonara { shift->com_exit }
-
-sub com_ft {
-    my ( $self, $rows ) = @_;
-    $self->rows( $rows ) if $rows;
-    $rows ||= $self->rows;
-    $self->update_status( $rows );
-    for my $tweet ( @{ $self->status } ) {
-        $self->output->print( $tweet->{ display } );
-    }
-    $self->output->print( '--- Last Update: '. strftime( '%Y-%m-%d %H:%M:%S', localtime() )." ---\n" );
-    1;
-}
-
-sub update_status {
-    my ( $self, $rows ) = @_;
-    my $id = 0;
-    $self->clear_status;
-    $self->status( [] );
-    for my $tweet ( @{ $self->client->friends_timeline( { rows => $rows } ) } ) {
-        $tweet->{ created_at } = DateTime::Format::DateParse->parse_datetime( $tweet->{ created_at } );
-        my $delaysec = time() - $tweet->{ created_at }->epoch;
-        $tweet->{ display } = $self->_build_display( $id, $delaysec, $tweet );
-        push @{ $self->status }, $tweet;
-        $id++;
-        last if $id >= $rows;
-    }
-}
-
-sub _build_display {
-    my ( $self, $id, $delaysec, $tweet ) = @_;
-    my $delaymin = int( $delaysec / 60 );
-    my $delayhour = int( $delaymin / 60 );
-    my $delayday = int( $delayhour / 24 );
-    $delayhour -= $delayday * 24 if $delayday;
-    $delaymin -= $delayhour * 60 if $delayhour;
-    $delaysec -= $delaymin * 60 if $delaymin;
-    my $delay = $delayday."Day ".sprintf("%02d",$delayhour).":".sprintf("%02d",$delaymin).":".sprintf("%02d",$delaysec);
-    "---\n[$id] ". $delay. " ago\n". '@'.$tweet->{user}{screen_name}. ': '. encode( "utf8", $tweet->{text} ). "\n";
-}
-
 __PACKAGE__->meta->make_immutable;
 
 no Mouse;
@@ -291,11 +176,9 @@ tweet body
 
  コンテナのような規格物であれば、すんなりシャシーに載せてフェリってもらえる。
 
-=head1 Commands
+=head1 CORE COMMANDS
 
-=head2 /help [ command ]
-
-show help
+These commands are provided by Cuitter::Plugin::Core.
 
 =head2 /exit /q /bye
 
@@ -305,6 +188,14 @@ exit from cuitter
 
 show friends timeline
 
+=head1 HELP COMMANDS
+
+These commands are provided by Cuitter::Plugin::Help.
+
+=head2 /help [ command ]
+
+show help
+
 =head1 LICENSE
 
 Artistic
