@@ -1,6 +1,7 @@
 package Cuitter::Plugin::Retweet;
 use Mouse::Role;
 use Encode;
+use Data::Dumper;
 
 requires qw( client status set_help com_ft );
 
@@ -10,11 +11,9 @@ sub _init_Retweet {
 }
 
 sub com_rt {
-    my ( $self, $id, @messages ) = @_;
-    my $message = "";
-    $message = join( " ", @messages ) if @messages;
+    my ( $self, $id ) = @_;
     my $tweet = $self->status->[ $id ];
-    $self->tweet( $message.' RT @'.$tweet->{user}{screen_name}. ': '. encode( "utf8", $tweet->{text} ) );
+    $self->tweet( 'RT @'.$tweet->{user}{screen_name}. ': '. encode( "utf8", $tweet->{text} ) );
     $self->com_ft;
     1;
 }
@@ -39,7 +38,7 @@ This plugin provides /rt command to cuitter.
 
 =head1 Provides Command
 
-=head2 /rt [ target-status-id ] [ message ]
+=head2 /rt [ target-status-id ] 
 
 Retweet to target tweet.
 
